@@ -207,5 +207,6 @@ def parse_sqlite_time(s: str) -> datetime:
         msg = f"Cannot parse date {s!r}"
         raise ValueError(msg) from e
 
-fn = os.path.expanduser('~/.docker-caching.sqlite')
+
+fn = os.path.expanduser("~/.dt-caches/docker-caching.sqlite")
 docker_caching = DockerCaching(fn=fn)
