@@ -76,7 +76,7 @@ def docker_pull(
         except KeyError:
             pass
         else:
-            logger.info("using cached pull info")
+            logger.info(f"using cached pull info for {image}")
 
             br2 = replace(br, digest=digest, tag=None)
             return DockerPullResult(br2, get_complete_tag(br2))
@@ -114,7 +114,7 @@ def docker_pull(
     logger.debug(f"Pulled {image} -> {ps.final_digest}")
 
     if not ps.final_digest:
-        raise PullError("could not find digest")
+        raise PullError(f"could not find final digest for {image} - perhaps docker failed. Please re-try.")
 
     br = parse_complete_tag(image)
     br2 = replace(br, digest=ps.final_digest, tag=None)
@@ -148,7 +148,9 @@ def yield_updates(updates: Iterator[dict]) -> Iterator[PullStatus]:
     yield PS
     # last_ps = ''
     last_progress = ""
+    all_lines = []
     for line in updates:
+        all_lines.append(line)
         # logger.info(line=line)
         # percentage = max(0.0, min(1.0, len(pushed) / max(1.0, len(layers)))) * 100.0
         if "progress" in line:
@@ -201,7 +203,8 @@ def yield_updates(updates: Iterator[dict]) -> Iterator[PullStatus]:
     PS.last_progress = f"Done: {PS.final_digest}"
     yield PS
     if PS.final_digest is None:
-        raise ZValueError("could not find digest")
+        msg = "Weird problem - I could not get the result of the pull"
+        raise ZValueError(msg, all_lines=all_lines)
         #
         # now = time.time()
         #
